@@ -1,4 +1,3 @@
-# $Id: en_us.pm 6 2004-12-28 23:33:59Z claco $
 package Handel::L10N::en_us;
 use strict;
 use warnings;
@@ -17,7 +16,11 @@ __END__
 
 =head1 NAME
 
-Handel::L10N::en_us - US English Language Pack
+Handel::L10N::en_us - US English Language Pack for Handel
+
+=head1 VERSION
+
+    $Id: en_us.pm 21 2004-12-30 05:06:55Z claco $
 
 =head1 AUTHOR
 
